pub fn is_mutation(kind: &FlatEventKind) -> boolExpand description
Returns true if this event kind represents an entity mutation (created, updated, or removed).
pub fn is_mutation(kind: &FlatEventKind) -> boolReturns true if this event kind represents an entity mutation (created, updated, or removed).